CKEDITOR.plugins.setLang("mathjax","uk",{title:"Математика у TeX",button:"Математика",dialogInput:"Наберіть тут на TeX'у",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"Документація про TeX",loading:"завантажується…",pathName:"математика"});