CKEDITOR.plugins.setLang("docprops","tr",{bgColor:"Arka Plan Rengi",bgFixed:"Sabit Arka Plan",bgImage:"Arka Plan Resim URLsi",charset:"Karakter Kümesi Kodlaması",charsetASCII:"ASCII",charsetCE:"Orta Avrupa",charsetCR:"Kiril",charsetCT:"Geleneksel Çince (Big5)",charsetGR:"Yunanca",charsetJP:"Japonca",charsetKR:"Korece",charsetOther:"Diğer Karakter Kümesi Kodlaması",charsetTR:"Türkçe",charsetUN:"Evrensel Kod (UTF-8)",charsetWE:"Batı Avrupa",chooseColor:"Seçiniz",design:"Dizayn",docTitle:"Sayfa Başlığı",
docType:"Belge Türü Başlığı",docTypeOther:"Diğer Belge Türü Başlığı",label:"Belge Özellikleri",margin:"Kenar Boşlukları",marginBottom:"Alt",marginLeft:"Sol",marginRight:"Sağ",marginTop:"Tepe",meta:"Tanım Bilgisi (Meta)",metaAuthor:"Yazar",metaCopyright:"Telif",metaDescription:"Belge Tanımı",metaKeywords:"Belge Dizinleme Anahtar Kelimeleri (virgülle ayrılmış)",other:"<diğer>",previewHtml:'<p>Bu bir <strong>örnek metindir</strong>. <a href="javascript:void(0)">CKEditor</a> kullanıyorsunuz.</p>',title:"Belge Özellikleri",
txtColor:"Yazı Rengi",xhtmlDec:"XHTML Bildirimlerini Dahil Et"});