html, body {
	margin:0;
	padding:0;
}
body{
	text-align: center;
	font-family: "Lucida Grande", "Lucida Sans Unicode", Verdana, Helvetica, Arial, sans-serif;
	background-color: #eee;
	color: #444;
	font-size: 75%;
}
a{
	color: #27D;
	text-decoration: none;
}
a:focus, a:hover, a:active {
	text-decoration: underline;
}
p, li {
	line-height: 1.8em;
}
h1, h2 {
    font-size: 18px;
    color: #666;
	margin: 0 0 10px 0;
	letter-spacing:-1px;
}
h1 {
	padding: 0;
	font-size: 3em;
	color: #333;
}
h2 {
	padding-top: 10px;
	font-size: 18px;
}
pre {
	font-size: 1.2em;
	line-height: 1.2em;
	overflow-x: auto;
}
div#page {
	width: 900px;
	background-color: #fff;
	margin: 0 auto;
	text-align: left;
	border-color: #ddd;
	border-style: none solid solid;
	border-width: medium 1px 1px;
}
div#container {
	padding: 20px;
}
div#ads {
	clear: both;
	padding: 12px 0 12px 66px;
}
div#footer {
	clear: both;
	color: #777;
	margin: 0 auto;
	padding: 20px 0 40px;
	text-align: center;
}
