CKEDITOR.plugins.setLang("mathjax","fa",{title:"ریاضیات در تک",button:"ریاضی",dialogInput:"فرمول خود را اینجا بنویسید",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"مستندسازی فرمول نویسی",loading:"بارگیری",pathName:"ریاضی"});