/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uploadwidget","ko",{abort:"사용자가 업로드를 중단했습니다.",doneOne:"파일이 성공적으로 업로드되었습니다.",doneMany:"파일 %1개를 성공적으로 업로드하였습니다.",uploadOne:"파일 업로드중 ({percentage}%)...",uploadMany:"파일 {max} 개 중 {current} 번째 파일 업로드 중 ({percentage}%)..."});