CKEDITOR.plugins.setLang("mathjax","eo",{title:"Matematiko en TeX",button:"Matematiko",dialogInput:"Skribu vian TeX tien",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"TeX dokumentado",loading:"estas ŝarganta",pathName:"matematiko"});