/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("placeholder","en-gb",{title:"Placeholder Properties",toolbar:"Placeholder",name:"Placeholder Name",invalidName:"The placeholder can not be empty and can not contain any of the following characters: [, ], <, >",pathName:"placeholder"});