CKEDITOR.plugins.setLang("docprops","pt",{bgColor:"Cor de Fundo",bgFixed:"Fundo Fixo",bgImage:"Caminho para a imagem de fundo",charset:"Codificação de caracteres",charsetASCII:"ASCII",charsetCE:"Europa Central",charsetCR:"Cirílico",charsetCT:"Chinês Traditional (Big5)",charsetGR:"Grego",charsetJP:"Japonês",charsetKR:"Coreano",charsetOther:"Outra Codificação de Caracteres",charsetTR:"Turco",charsetUN:"Unicode (UTF-8)",charsetWE:"Europa Ocidental",chooseColor:"Choose",design:"Desenho",docTitle:"Título da Página",
docType:"Tipo de Cabeçalho do Documento",docTypeOther:"Outro Tipo de Cabeçalho do Documento",label:"Propriedades do Documento",margin:"Margem das Páginas",marginBottom:"Fundo",marginLeft:"Esquerda",marginRight:"Direita",marginTop:"Topo",meta:"Meta Data",metaAuthor:"Autor",metaCopyright:"Direitos de Autor",metaDescription:"Descrição do Documento",metaKeywords:"Palavras de Indexação do Documento (separadas por virgula)",other:"<outro>",previewHtml:'<p>Isto é algum <strong>texto amostra</strong>. Está a usar o <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"Propriedades do documento",txtColor:"Cor do Texto",xhtmlDec:"Incluir Declarações XHTML"});