CKEDITOR.plugins.setLang("docprops","sv",{bgColor:"Bakgrundsfärg",bgFixed:"Fast bakgrund",bgImage:"Bakgrundsbildens URL",charset:"Teckenuppsättningar",charsetASCII:"ASCII",charsetCE:"Central Europa",charsetCR:"Kyrillisk",charsetCT:"Traditionell Kinesisk (Big5)",charsetGR:"Grekiska",charsetJP:"Japanska",charsetKR:"Koreanska",charsetOther:"Övriga teckenuppsättningar",charsetTR:"Turkiska",charsetUN:"Unicode (UTF-8)",charsetWE:"Väst Europa",chooseColor:"Välj",design:"Design",docTitle:"Sidtitel",docType:"Sidhuvud",
docTypeOther:"Övriga sidhuvuden",label:"Dokumentegenskaper",margin:"Sidmarginal",marginBottom:"Botten",marginLeft:"Vänster",marginRight:"Höger",marginTop:"Topp",meta:"Metadata",metaAuthor:"Författare",metaCopyright:"Upphovsrätt",metaDescription:"Sidans beskrivning",metaKeywords:"Sidans nyckelord (kommaseparerade)",other:"Annan...",previewHtml:'<p>Detta är en <strong>exempel text</strong>. Du använder <a href="javascript:void(0)">CKEditor</a>.</p>',title:"Dokumentegenskaper",txtColor:"Textfärg",xhtmlDec:"Inkludera XHTML deklaration"});