CKEDITOR.plugins.setLang("mathjax","fi",{title:"Matematiikkaa TeX:llä",button:"Matematiikka",dialogInput:"Kirjoita TeX:iä tähän",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"TeX dokumentaatio",loading:"lataa...",pathName:"matematiikka"});