/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","hu",{title:"UI Színválasztó",preview:"Élő előnézet",config:"Illessze be ezt a szöveget a config.js fájlba",predefined:"Előre definiált színbeállítások"});