/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("uicolor","vi",{title:"Giao diện người dùng Color Picker",preview:"Xem trước trực tiếp",config:"Dán chuỗi này vào tập tin config.js của bạn",predefined:"Tập màu định nghĩa sẵn"});