/*
 Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang("filetools","sv",{loadError:"Fel uppstod vid filläsning",networkError:"Nätverksfel uppstod vid filuppladdning.",httpError404:"HTTP-fel uppstod vid filuppladdning (404: Fil hittades inte).",httpError403:"HTTP-fel uppstod vid filuppladdning (403: Förbjuden).",httpError:"HTTP-fel uppstod vid filuppladdning (felstatus: %1).",noUrlError:"URL för uppladdning inte definierad.",responseError:"Felaktigt serversvar."});